#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 idris
version:              1.3.3
visibility:           public
id:                   idris-1.3.3-697v80K58q3PVtmlf6zaU
key:                  idris-1.3.3-697v80K58q3PVtmlf6zaU
license:              BSD-3-Clause
maintainer:           Niklas Larsson <niklas@mm.st>
author:               Edwin Brady
stability:            Beta
homepage:             https://www.idris-lang.org/
synopsis:             Functional Programming Language with Dependent Types
description:
    Idris is a general purpose language with full dependent types.
    It is compiled, with eager evaluation.
    Dependent types allow types to be predicated on values,
    meaning that some aspects of a program'\''s behaviour can be
    specified precisely in the type. The language is closely
    related to Epigram and Agda. There is a tutorial at
    <https://www.idris-lang.org/documentation>.
    Features include:

    * Full, first class, dependent types with dependent pattern matching

    * where clauses, with rule, case expressions,
    pattern matching let and lambda bindings

    * Interfaces (similar to type classes), monad comprehensions

    * do notation, idiom brackets, syntactic conveniences for lists,
    tuples, dependent pairs

    * Totality checking

    * Coinductive types

    * Indentation significant syntax, extensible syntax

    * Cumulative universes

    * Simple foreign function interface (to C)

    * Hugs style interactive environment

category:             Compilers/Interpreters, Dependent Types
abi:                  41682f21e64fc9552d10d5a9266b21e3
exposed:              True
exposed-modules:
    IRTS.Bytecode IRTS.CodegenC IRTS.CodegenCommon
    IRTS.CodegenJavaScript IRTS.Compiler IRTS.Defunctionalise
    IRTS.DumpBC IRTS.Exports IRTS.Inliner IRTS.JavaScript.AST
    IRTS.JavaScript.Codegen IRTS.JavaScript.LangTransforms
    IRTS.JavaScript.Name IRTS.JavaScript.PrimOp
    IRTS.JavaScript.Specialize IRTS.Lang IRTS.LangOpts IRTS.Portable
    IRTS.Simplified IRTS.System Idris.ASTUtils Idris.AbsSyntax
    Idris.AbsSyntaxTree Idris.Apropos Idris.CaseSplit Idris.Chaser
    Idris.CmdOptions Idris.Colours Idris.Completion Idris.Core.Binary
    Idris.Core.CaseTree Idris.Core.Constraints Idris.Core.DeepSeq
    Idris.Core.Elaborate Idris.Core.Evaluate Idris.Core.Execute
    Idris.Core.ProofState Idris.Core.ProofTerm Idris.Core.TT
    Idris.Core.Typecheck Idris.Core.Unify Idris.Core.WHNF
    Idris.Coverage Idris.DSL Idris.DataOpts Idris.DeepSeq
    Idris.Delaborate Idris.Directives Idris.Docs Idris.Docstrings
    Idris.Elab.AsPat Idris.Elab.Clause Idris.Elab.Data
    Idris.Elab.Implementation Idris.Elab.Interface Idris.Elab.Provider
    Idris.Elab.Quasiquote Idris.Elab.Record Idris.Elab.Rewrite
    Idris.Elab.RunElab Idris.Elab.Term Idris.Elab.Transform
    Idris.Elab.Type Idris.Elab.Utils Idris.Elab.Value Idris.ElabDecls
    Idris.Erasure Idris.ErrReverse Idris.Error Idris.Help Idris.IBC
    Idris.IdeMode Idris.IdrisDoc Idris.Imports Idris.Info
    Idris.Info.Show Idris.Inliner Idris.Interactive Idris.Main
    Idris.ModeCommon Idris.Options Idris.Output Idris.Package
    Idris.Package.Common Idris.Package.Parser Idris.Parser
    Idris.Parser.Data Idris.Parser.Expr Idris.Parser.Helpers
    Idris.Parser.Ops Idris.Parser.Stack Idris.PartialEval
    Idris.Primitives Idris.ProofSearch Idris.Prover Idris.Providers
    Idris.REPL Idris.REPL.Browse Idris.REPL.Commands Idris.REPL.Parser
    Idris.Reflection Idris.Termination Idris.Transforms
    Idris.TypeSearch Idris.Unlit Idris.WhoCalls Util.DynamicLinker
    Util.ScreenSize Util.System

hidden-modules:
    Util.Pretty Util.Net Paths_idris Version_idris Tools_idris
    BuildFlags_idris

import-dirs:          /usr/lib/ghc-9.0.1/site-local/idris-1.3.3
library-dirs:         /usr/lib/ghc-9.0.1/site-local/idris-1.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/idris
hs-libraries:         HSidris-1.3.3-697v80K58q3PVtmlf6zaU
extra-libraries:      gmp
depends:
    aeson-1.5.6.0-HjRPlMbeXBZ4yuplu15455
    annotated-wl-pprint-0.7.0-70TwcJulbP410FZMDCXWmO
    ansi-terminal-0.11-AWG4ISlY8CcEJlJfIhaQcb
    ansi-wl-pprint-0.6.9-JOR1fZe7W518IeuVMlK4KV array-0.5.4.0
    async-2.2.3-KG7Du60y7DvAqBDAYoSjqL base-4.15.0.0
    base64-bytestring-1.2.1.0-GF7RNKVUXzr7ftO0CMZbPs binary-0.8.8.0
    blaze-html-0.9.1.2-LSMqXlgq2DDHc3OlwhOnTC
    blaze-markup-0.8.2.8-17Ckl6PgrahHdxhCd9dsds bytestring-0.10.12.1
    cheapskate-0.1.1.2-2Jot3DcZA7E4nPeHBZul86
    code-page-0.2.1-CYVTpGA5RICHN6wyF6l377 containers-0.6.4.1
    deepseq-1.4.5.0 directory-1.3.6.1 filepath-1.4.2.1
    fingertree-0.1.4.2-4Bj9qAMGkaiKk1BoHEFaMr
    fsnotify-0.3.0.1-Lnl4uC7d9eU1sDb3hgE6CV haskeline-0.8.1.0
    ieee754-0.8.0-DCmgNmM9a4g4zjg2yOVRf
    libffi-0.1-6JV49STIEUfA7HvLqLSQvL
    megaparsec-9.1.0-3baosRTM6G61cXADCCGeP9 mtl-2.2.2
    network-3.1.2.2-AIHAQTgcOP2p9DGqwUMBL
    optparse-applicative-0.16.1.0-GAf19vjqBowD5QTDnxMOQQ
    parser-combinators-1.3.0-5jHqYWwdpCqFWQLuYLRvi6 pretty-1.1.3.6
    process-1.6.11.0 regex-tdfa-1.3.1.1-8KBKH3EsotI2v3BWqoG8PB
    safe-0.3.19-BCcHjTM7bV690cTfMWPidj
    split-0.2.3.4-66WnL8lpKgJ9suCZaVklHQ
    terminal-size-0.3.2.1-8rLUbNor4uN6iQgtxjW6lw text-1.2.4.1
    time-1.9.3 transformers-0.5.6.2
    uniplate-1.6.13-Hj86p3lF2Ye19njgJIf2eb unix-2.7.2.2
    unordered-containers-0.2.14.0-Wie4T3gD5k18ShmuaDNll
    utf8-string-1.0.2-FSV4F6pxd5y7PjtRkbEpDf
    vector-0.12.3.1-KJ02XewdvWJHGa2GVFsQSX
    vector-binary-instances-0.2.5.2-79nIHtq9ImZ68bOsafpSut
    zip-archive-0.4.1-3PRIiqRTkDY2bOkq9S2KhG

haddock-interfaces:   /usr/share/doc/idris/html/idris.haddock
haddock-html:         /usr/share/doc/idris/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

